@@ -1,6 +1,6 @@
 /*--
 
- $Id: Format.java,v 1.1.1.1 2005/12/02 14:16:51 fbusquets Exp $
+ $Id: Format.java,v 1.2 2013-03-01 23:21:46 fbusquets Exp $
 
  Copyright (C) 2000-2004 Jason Hunter & Brett McLaughlin.
  All rights reserved.
@@ -68,13 +68,13 @@ import java.lang.reflect.Method;
  * Several modes are available to effect the way textual content is printed.
  * See the documentation for {@link TextMode} for details.
  *
- * @version $Revision: 1.1.1.1 $, $Date: 2005/12/02 14:16:51 $
+ * @version $Revision: 1.2 $, $Date: 2013-03-01 23:21:46 $
  * @author Jason Hunter
  */
 public class Format implements Cloneable {
 
     private static final String CVS_ID =
-            "@(#) $RCSfile: Format.java,v $ $Revision: 1.1.1.1 $ $Date: 2005/12/02 14:16:51 $ $Name:  $";
+            "@(#) $RCSfile: Format.java,v $ $Revision: 1.2 $ $Date: 2013-03-01 23:21:46 $ $Name:  $";
 
     /**
      * Returns a new Format object that performs no whitespace changes, uses
@@ -457,8 +457,11 @@ public class Format implements Cloneable {
                     Class encoderClass = Class.forName("java.nio.charset.CharsetEncoder");
                     Method forName = charsetClass.getMethod("forName", new Class[]{String.class});
                     Object charsetObj = forName.invoke(null, new Object[]{encoding});
-                    Method newEncoder = charsetClass.getMethod("newEncoder", null);
-                    encoder = newEncoder.invoke(charsetObj, null);
+
+                    // MODIFIED: Added (Class[]) and (Object[]) cast sentences in "null" parameters
+                    // to avoid warnings during compilation
+                    Method newEncoder = charsetClass.getMethod("newEncoder", (Class[])null);
+                    encoder = newEncoder.invoke(charsetObj, (Object[])null);
                     canEncode = encoderClass.getMethod("canEncode", new Class[]{char.class});
                 }
                 catch (Exception ignored) {
