@@ -107,70 +107,70 @@ public class MediaBagMultiEditorPanel extends EditorPanel {
      * WARNING: Do NOT modify this code. The content of this method is
      * always regenerated by the Form Editor.
      */
-    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
-    private void initComponents() {
-        java.awt.GridBagConstraints gridBagConstraints;
+  // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
+  private void initComponents() {
+    java.awt.GridBagConstraints gridBagConstraints;
 
-        bGroup = new javax.swing.ButtonGroup();
-        mainPanel = new javax.swing.JPanel();
-        filterPanel = new javax.swing.JPanel();
-        filterLb = new javax.swing.JLabel();
-        filterCombo = new javax.swing.JComboBox(getComboItems().toArray());
-        scrollPanel = new javax.swing.JScrollPane();
-        sPanel = new ThumbsExplorerPanel();
-        statusLb = new javax.swing.JLabel();
-        elementEditPanel = new MediaBagElementEditorPanel(options);
+    bGroup = new javax.swing.ButtonGroup();
+    mainPanel = new javax.swing.JPanel();
+    filterPanel = new javax.swing.JPanel();
+    filterLb = new javax.swing.JLabel();
+    filterCombo = new javax.swing.JComboBox<Object>(getComboItems().toArray());
+    scrollPanel = new javax.swing.JScrollPane();
+    sPanel = new ThumbsExplorerPanel();
+    statusLb = new javax.swing.JLabel();
+    elementEditPanel = new MediaBagElementEditorPanel(options);
 
-        setLayout(new java.awt.BorderLayout());
+    setLayout(new java.awt.BorderLayout());
 
-        mainPanel.setLayout(new java.awt.GridBagLayout());
+    mainPanel.setLayout(new java.awt.GridBagLayout());
 
-        filterPanel.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.LEFT));
+    filterPanel.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.LEFT));
 
-        filterLb.setText(options.getMsg("edit_media_show_type"));
-        filterPanel.add(filterLb);
+    filterLb.setText(options.getMsg("edit_media_show_type"));
+    filterPanel.add(filterLb);
 
-        filterCombo.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(java.awt.event.ActionEvent evt) {
-                filterComboActionPerformed(evt);
-            }
-        });
-        filterPanel.add(filterCombo);
+    filterCombo.addActionListener(new java.awt.event.ActionListener() {
+      public void actionPerformed(java.awt.event.ActionEvent evt) {
+        filterComboActionPerformed(evt);
+      }
+    });
+    filterPanel.add(filterCombo);
 
-        gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
-        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
-        mainPanel.add(filterPanel, gridBagConstraints);
+    gridBagConstraints = new java.awt.GridBagConstraints();
+    gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
+    gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
+    mainPanel.add(filterPanel, gridBagConstraints);
 
-        scrollPanel.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
-        scrollPanel.addComponentListener(new java.awt.event.ComponentAdapter() {
-            public void componentResized(java.awt.event.ComponentEvent evt) {
-                scrollPanelComponentResized(evt);
-            }
-        });
-        scrollPanel.setViewportView(sPanel);
+    scrollPanel.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
+    scrollPanel.addComponentListener(new java.awt.event.ComponentAdapter() {
+      public void componentResized(java.awt.event.ComponentEvent evt) {
+        scrollPanelComponentResized(evt);
+      }
+    });
+    scrollPanel.setViewportView(sPanel);
 
-        gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
-        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
-        gridBagConstraints.weightx = 1.0;
-        gridBagConstraints.weighty = 1.0;
-        mainPanel.add(scrollPanel, gridBagConstraints);
+    gridBagConstraints = new java.awt.GridBagConstraints();
+    gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
+    gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
+    gridBagConstraints.weightx = 1.0;
+    gridBagConstraints.weighty = 1.0;
+    mainPanel.add(scrollPanel, gridBagConstraints);
 
-        statusLb.setText("0 "+options.getMsg("edit_media_objects"));
-        gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
-        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
-        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
-        mainPanel.add(statusLb, gridBagConstraints);
-        gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
-        gridBagConstraints.fill = java.awt.GridBagConstraints.VERTICAL;
-        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
-        mainPanel.add(elementEditPanel, gridBagConstraints);
+    statusLb.setText("0 "+options.getMsg("edit_media_objects"));
+    gridBagConstraints = new java.awt.GridBagConstraints();
+    gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
+    gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
+    gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
+    mainPanel.add(statusLb, gridBagConstraints);
+    gridBagConstraints = new java.awt.GridBagConstraints();
+    gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
+    gridBagConstraints.fill = java.awt.GridBagConstraints.VERTICAL;
+    gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
+    mainPanel.add(elementEditPanel, gridBagConstraints);
 
-        add(mainPanel, java.awt.BorderLayout.CENTER);
-    }// </editor-fold>//GEN-END:initComponents
+    add(mainPanel, java.awt.BorderLayout.CENTER);
+  }// </editor-fold>//GEN-END:initComponents
     
     private void filterComboActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_filterComboActionPerformed
         
@@ -346,16 +346,16 @@ public class MediaBagMultiEditorPanel extends EditorPanel {
         
     
     
-    // Variables declaration - do not modify//GEN-BEGIN:variables
-    private javax.swing.ButtonGroup bGroup;
-    private javax.swing.JPanel elementEditPanel;
-    private javax.swing.JComboBox filterCombo;
-    private javax.swing.JLabel filterLb;
-    private javax.swing.JPanel filterPanel;
-    private javax.swing.JPanel mainPanel;
-    private javax.swing.JPanel sPanel;
-    private javax.swing.JScrollPane scrollPanel;
-    private javax.swing.JLabel statusLb;
-    // End of variables declaration//GEN-END:variables
+  // Variables declaration - do not modify//GEN-BEGIN:variables
+  private javax.swing.ButtonGroup bGroup;
+  private javax.swing.JPanel elementEditPanel;
+  private javax.swing.JComboBox<Object> filterCombo;
+  private javax.swing.JLabel filterLb;
+  private javax.swing.JPanel filterPanel;
+  private javax.swing.JPanel mainPanel;
+  private javax.swing.JPanel sPanel;
+  private javax.swing.JScrollPane scrollPanel;
+  private javax.swing.JLabel statusLb;
+  // End of variables declaration//GEN-END:variables
     
 }
