@@ -246,7 +246,7 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         lbY = new javax.swing.JLabel();
         yTxt = new javax.swing.JTextField();
         lbLocFrom = new javax.swing.JLabel();
-        locFromCombo = new javax.swing.JComboBox(locationFromNames.toArray());
+        locFromCombo = new javax.swing.JComboBox<Object>(locationFromNames.toArray());
         catchMouseChk = new javax.swing.JCheckBox();
         stretchChk = new javax.swing.JCheckBox();
 
@@ -478,9 +478,9 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
         filePanelCard2.add(lbLength, gridBagConstraints);
 
-        lengthEditor.setMax(15);
-        lengthEditor.setValue(5);
+        lengthEditor.setMax(180);
         lengthEditor.setMin(1);
+        lengthEditor.setValue(5);
         lengthEditor.addPropertyChangeListener(SmallIntEditor.PROP_VALUE, this);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -777,15 +777,15 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
     
     protected void selectBtnPressed(){
         String value=null;
-        JList list=null;
+        JList<Object> list=null;
         String dlgTitleKey=null;
         
         if(mc.mediaType==MediaContent.RUN_CLIC_ACTIVITY){
-            list=new JList(mbe.getProjectEditor().getActivityBagEditor().getListModel());
+            list=new JList<Object>(mbe.getProjectEditor().getActivityBagEditor().getListModel());
             dlgTitleKey="edit_mc_activity_selection";
         }
         else if(mc.mediaType==MediaContent.RUN_CLIC_PACKAGE){            
-            list=new JList(mbe.getProjectEditor().getActivitySequenceEditor().getTagList());
+            list=new JList<Object>(mbe.getProjectEditor().getActivitySequenceEditor().getTagList());
             dlgTitleKey="edit_mc_sequence_selection";
         }
         
@@ -952,7 +952,7 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
     private javax.swing.JLabel lbY;
     private edu.xtec.jclic.beans.SmallIntEditor lengthEditor;
     private edu.xtec.jclic.beans.SmallIntEditor levelEditor;
-    private javax.swing.JComboBox locFromCombo;
+    private javax.swing.JComboBox<Object> locFromCombo;
     private javax.swing.JPanel locationPanel;
     private javax.swing.JCheckBox loopChk;
     private javax.swing.JPanel mainPanel;
