@@ -238,8 +238,39 @@ public class ActivityBag extends Object implements Editable, Domable, Listener {
             if(dp!=null && dp.containsKey(name) && (type==null || type.equals(dp.get(name))))
                 map.put("["+project.getBridge().getMsg("edit_project")+"]", Constants.PROJECT_OBJECT);            
         }
+        
+        if(project.settings.coverFileName != null){
+          MediaBagElement mbe = project.mediaBag.getElementByFileName(project.settings.coverFileName);
+          if(mbe!=null && name.equals(mbe.getName()))
+            map.put(name, Constants.PROJECT_OBJECT);
+        }
+        
+        if(project.settings.thumbnailFileName != null){
+          MediaBagElement mbe = project.mediaBag.getElementByFileName(project.settings.thumbnailFileName);
+          if(mbe!=null && name.equals(mbe.getName()))
+            map.put(name, Constants.PROJECT_OBJECT);            
+        }
+        
+        if(project.settings.icon16 != null){
+          MediaBagElement mbe = project.mediaBag.getElementByFileName(project.settings.icon16);
+          if(mbe!=null && name.equals(mbe.getName()))
+            map.put(name, Constants.PROJECT_OBJECT);
+        }
+
+        if(project.settings.icon72 != null){
+          MediaBagElement mbe = project.mediaBag.getElementByFileName(project.settings.icon72);
+          if(mbe!=null && name.equals(mbe.getName()))
+            map.put(name, Constants.PROJECT_OBJECT);
+        }
+        
+        if(project.settings.icon192 != null){
+          MediaBagElement mbe = project.mediaBag.getElementByFileName(project.settings.icon192);
+          if(mbe!=null && name.equals(mbe.getName()))
+            map.put(name, Constants.PROJECT_OBJECT);
+        }                
     }
     
+    @Override
     public void listReferences(String type, Map<String, String> map) {
         for(int i=0; i<size(); i++){
             ActivityBagElement abe=elementAt(i);
