@@ -103,9 +103,15 @@ public abstract class ZipFileSystem extends FileSystem {
     
     @Override
     public boolean fileExists(String fName){
-        return super.fileExists(fName);
+      return getEntry(fName)!=null;
     }
     
+    @Override
+    public boolean realFileExists(String fName){
+      return super.fileExists(fName);
+    }
+    
+    
     @Override
     public long getFileLength(String fileName) throws IOException{
         ExtendedZipEntry entry;
