@@ -28,6 +28,7 @@ import edu.xtec.jclic.edit.Editor;
 import edu.xtec.jclic.fileSystem.FileSystem;
 import edu.xtec.jclic.fileSystem.ZipFileSystem;
 import edu.xtec.jclic.media.EventSounds;
+import edu.xtec.jclic.misc.Utils;
 import edu.xtec.jclic.skins.Skin;
 import edu.xtec.util.Domable;
 import edu.xtec.util.JDomUtility;
@@ -37,6 +38,7 @@ import edu.xtec.util.StrUtils;
 import java.io.*;
 import java.util.*;
 import java.util.zip.*;
+import org.json.JSONObject;
 
 /**
  *
@@ -66,6 +68,7 @@ public class JClicProject extends Object implements Editable, Domable {
     public String code;
     
     protected String fullPath;
+    public boolean isScorm;
         
     public static String TYPE="type";
     
@@ -74,6 +77,7 @@ public class JClicProject extends Object implements Editable, Domable {
         this.fileSystem=fileSystem;
         this.bridge=bridge;
         this.fullPath = (fullPath==null ? "" : fullPath);
+        isScorm = this.fullPath.endsWith(".scorm.zip");
         version=CURRENT_VERSION;
         settings=new ProjectSettings();
         settings.title=bridge.getMsg("UNNAMED");
@@ -139,6 +143,10 @@ public class JClicProject extends Object implements Editable, Domable {
         mediaBag.setProperties(e.getChild(MediaBag.ELEMENT_NAME), null);        
     }
     
+    public void readJSON(JSONObject json, boolean preserve) throws Exception {
+      settings.readJSON(json, this, preserve);
+    }
+    
     public static JClicProject getJClicProject(org.jdom.Element e, ResourceBridge rb, FileSystem fs, String fullPath) throws Exception{
         JClicProject jcp=new JClicProject(rb, fs, fullPath);
         //jcp.load(e);
@@ -159,26 +167,40 @@ public class JClicProject extends Object implements Editable, Domable {
         if(fullPath.startsWith("file://"))
             fullPath=fullPath.substring(7);
                             
-        String projectName;
-        if(fullPath.endsWith(".jclic.zip")){
+        String projectName = null;
+        JSONObject json=null;
+        if(fullPath.endsWith(Utils.EXT_JCLIC_ZIP)){
             fileSystem=FileSystem.createFileSystem(fullPath, rb);
             String[] projects=((ZipFileSystem)fileSystem).getEntries(".jclic");
             if(projects==null)
                 throw new Exception("File "+fullPath+" does not contain any jclic project");
             projectName=projects[0];
         }
+        else if(fullPath.endsWith(Utils.EXT_SCORM_ZIP)){
+            fileSystem=FileSystem.createFileSystem(fullPath, rb);
+            if(fileSystem.fileExists("project.json")){
+              json = new JSONObject(new String(fileSystem.getBytes("project.json")));
+              projectName = json.optString("mainFile", null);
+            }
+            if(projectName == null)
+              throw new Exception("Invalid JClic SCORM file: " + fullPath);
+        }
         else{
             fileSystem=new FileSystem(FileSystem.getPathPartOf(fullPath), rb);
             projectName=FileSystem.getFileNameOf(fullPath);
+            if(fileSystem.fileExists("project.json"))
+              json = new JSONObject(new String(fileSystem.getBytes("project.json")));
         }
                             
         if(projectName.endsWith(".jclic")){
             org.jdom.Document doc=fileSystem.getXMLDocument(projectName);
             System.gc();            
-            result=getJClicProject(doc.getRootElement(), rb, fileSystem, fullPath);            
+            result=getJClicProject(doc.getRootElement(), rb, fileSystem, fullPath);
         }
 
         if(result!=null){
+            if(json!=null)
+              result.readJSON(json, false);          
             result.mediaBag.waitForAllImages();
             //System.gc();
         }
